@@ -84,6 +84,7 @@ OC.L10N.register(
     "Accept" : "Aanvaar",
     "Remove" : "Verwyder",
     "email" : "e-pos",
+    "Choose target folder" : "Kies teikenvouer",
     "Other" : "Ander",
     "Forward" : "Stuur aan",
     "View source" : "Bekyk bron",
@@ -92,10 +93,10 @@ OC.L10N.register(
     "Import into calendar" : "Voer in na kalender",
     "Download attachment" : "Laai aanhangsel af",
     "Move" : "Skuif",
-    "Loading …" : "Laai …",
     "Remove account" : "Verwyder rekening",
-    "Quota" : "Kwota",
+    "Add folder" : "Voeg 'n gids by",
     "Saving" : "Stoor tans",
+    "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
     "Reply" : "Antwoord",
     "Retry" : "Herprobeer",
