@@ -135,6 +135,7 @@ OC.L10N.register(
     "domain" : "dominiu",
     "Remove" : "Quitar",
     "Loading messages …" : "Cargando los mensaxes…",
+    "Choose target folder" : "Escoyer la carpeta de destín",
     "No more submailboxes in here" : "Equí nun hai más sobandexes",
     "Important info" : "Información importante",
     "Forward" : "Avanzar",
@@ -151,18 +152,19 @@ OC.L10N.register(
     "Show images temporarily" : "Amosar les imáxenes temporalmente",
     "Quoted text" : "Cita",
     "Move" : "Mover",
-    "Loading …" : "Cargando…",
-    "Not supported by the server" : "Nun ye compatible col sirvidor",
-    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
     "Remove account" : "Quitar la cuenta",
     "Remove {email}" : "Quitar {email}",
-    "Quota" : "Cuota",
+    "Add folder" : "Amestar una carpeta",
+    "Folder name" : "Nome de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Xubir",
     "Move down" : "Baxar",
+    "Show all folders" : "Amosar toles carpetes",
     "Collapse mailboxes" : "Contrayer toles bandexes",
     "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
+    "Loading …" : "Cargando…",
     "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
+    "Delete folder" : "Desaniciar la carpeta",
     "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Rename" : "Renomar",
     "Outbox" : "Bandexa de salida",
