@@ -102,6 +102,7 @@ OC.L10N.register(
     "Trusted senders" : "Доверени податели",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
     "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
+    "Install Mailvelope browser extension" : "Инсталирайте разширението за браузър Mailvelope",
     "About" : "Относно",
     "Keyboard shortcuts" : "Бързи клавиши",
     "Compose new message" : "Създай ново съобщение",
@@ -173,6 +174,7 @@ OC.L10N.register(
     "Confirm" : "Потвърдете",
     "Plain text" : "Обикновен текст",
     "Rich text" : "Форматиран текст",
+    "No messages in this folder" : "Няма съобщения",
     "No messages" : "Няма съобщения.",
     "Blind copy recipients only" : "Само получателите на слепи копия",
     "No subject" : "Без /няма/ тема",
@@ -247,6 +249,7 @@ OC.L10N.register(
     "Itinerary for {type} is not supported yet" : "Маршрутът за {type} все още не се поддържа",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
     "Loading messages …" : "Зареждане на съобщения ...",
+    "Choose target folder" : "Избор на папка",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
     "Important info" : "Важна информация",
@@ -286,26 +289,30 @@ OC.L10N.register(
     "Moving" : "Преместване ",
     "Moving thread" : "Нишката се премества",
     "Moving message" : "Съобщението се премества",
-    "Loading …" : "Зарежда …",
-    "Not supported by the server" : "Не се поддържа от сървъра",
-    "{usage} of {limit} used" : "{usage} от {limit}  използвани",
     "Remove account" : "Изтриване",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Профилът за {email} и кешираните имейл данни ще бъдат премахнати от Nextcloud, но не и от вашия доставчик на електронна поща.",
     "Remove {email}" : "Премахване {email}",
     "Provisioned account is disabled" : "Осигуреният профил е деактивиран",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Моля, да се впишете с парола, за да активирате този профил. Текущата сесия използва удостоверяване без парола, напр. SSO или WebAuthn.",
-    "Quota" : "Квота",
+    "Add folder" : "Добави папка",
+    "Folder name" : "Име на папка",
     "Saving" : "Запазване",
     "Move up" : "Преместване нагоре",
     "Move down" : "Преместване  надолу",
+    "Show all folders" : "Покажи всички папки",
     "Collapse mailboxes" : "Свиване на пощенските кутии",
     "_{total} message_::_{total} messages_" : ["{total} съобщения","{total} съобщения"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
+    "Loading …" : "Зарежда …",
     "All messages in mailbox will be deleted." : "Всички съобщения в пощенската кутия ще бъдат изтрити.",
     "Clear mailbox {name}" : "Изчистване на пощенска кутия {name}",
+    "Delete folder" : "Изтриване на папка",
     "An error occurred, unable to rename the mailbox." : "Възникна грешка, не можа да се преименува пощенската кутия.",
     "Mark all as read" : "Маркирай всички като прочетени",
+    "Mark all messages of this folder as read" : "Маркирай всички съобщения в папката като прочетени",
+    "Add subfolder" : "Добави подпапка",
     "Rename" : "Преименуване",
+    "Move folder" : "Преместване на папка",
     "Clear cache" : "Изтриване на кеша",
     "Clear locally cached data, in case there are issues with synchronization." : "Изчистете локално кеширани данни, в случай че има проблеми със синхронизирането.",
     "Subscribed" : "Абониран",
