@@ -57,6 +57,7 @@ OC.L10N.register(
     "Choose" : "Dewisa",
     "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
     "Confirm" : "Cadarnhau",
+    "No messages in this folder" : "Dim negeseuon yn y ffolder hon",
     "Favorite" : "Ffefryn",
     "Back" : "Nôl",
     "Create event" : "Creu digwyddiad",
@@ -79,10 +80,13 @@ OC.L10N.register(
     "Save all to Files" : "Cadw'r cyfan i Ffeiliau",
     "The images have been blocked to protect your privacy." : "Mae'r delweddau wedi'u rhwystro i ddiogelu eich preifatrwydd.",
     "Move" : "Symud",
-    "Loading …" : "Yn llwytho …",
     "Remove account" : "Dileu cyfrif",
+    "Add folder" : "Ychwanegu ffolder",
+    "Show all folders" : "Dangos pob ffolder",
+    "Loading …" : "Yn llwytho …",
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
     "Mark all messages of this folder as read" : "Marcio'r holl negeseuon y ffolder hon fel y'u darllenwyd",
+    "Add subfolder" : "Ychwanegu is-ffolder",
     "Rename" : "Ailenwi",
     "New message" : "Neges newydd",
     "Error sending your message" : "Gwall wrth anfon eich neges",
