@@ -199,6 +199,7 @@ OC.L10N.register(
     "email" : "Ηλ.Ταχυδρομείο",
     "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
     "Loading messages …" : "Φόρτωση μηνυμάτων ...",
+    "Choose target folder" : "Επιλογή φακέλου προορισμού",
     "No more submailboxes in here" : "Δεν υπάρχουν άλλα υπο-γραμματοκιβώτια εδώ",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Τα μηνύματα θα επισημανθούν αυτόματα ως σημαντικά με βάση αυτά με τα οποία επισημαίνετε ως σημαντικά. Στην αρχή ίσως χρειαστεί να τα αλλάζετε χειροκίνητα, έως ότου εκπαιδευτεί το σύστημα, αλλά θα βελτιώνεται σταδιακά με την πάροδο του χρόνου.",
     "Important info" : "Σημαντική πλροφορία",
@@ -235,26 +236,29 @@ OC.L10N.register(
     "Moving" : "Μετακινείται",
     "Moving thread" : "Μετακίνηση νήματος",
     "Moving message" : "Μετακίνηση μηνύματος",
-    "Loading …" : "Φόρτωση…",
-    "Not supported by the server" : "Δεν υποστηρίζεται από τον διακομιστή",
-    "{usage} of {limit} used" : "Σε χρήση {usage} από {limit}",
     "Remove account" : "Αφαίρεση λογαριασμού",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Ο λογαριασμός για {email} και προσωρινά αποθηκευμένα δεδομένα email θα καταργηθεί από το Nextcloud, αλλά όχι από τον πάροχο email σας.",
     "Remove {email}" : "Αφαίρεση {email}",
-    "Quota" : "Σύνολο χώρου",
     "Show only subscribed folders" : "Εμφάνιση μόνο εγγεγραμμένων φακέλων",
+    "Folder name" : "Όνομα φακέλου",
     "Saving" : "Αποθήκευση",
     "Move up" : "Μετακίνηση επάνω",
     "Move down" : "Μετακίνηση Κάτω",
     "Show all subscribed folders" : "Εμφάνιση όλων των εγγεγραμμένων φακέλων",
+    "Show all folders" : "Εμφάνιση όλων των φακέλων",
     "Collapse mailboxes" : "Σύμπτυξη γραμματοκιβωτίων",
     "_{total} message_::_{total} messages_" : ["{total} μήνυμα","{total} μηνύματα"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} μη αναγνωσμένο από {total}","{unread} μη αναγνωσμένα από {total}"],
+    "Loading …" : "Φόρτωση…",
+    "The folder and all messages in it will be deleted." : "Ο φάκελος και όλα τα μηνύματα σε αυτόν θα διαγραφούν.",
+    "Delete folder" : "Διαγραφή φακέλου",
     "Delete folder {name}" : "Διαγραφή του φακέλου {name}",
     "An error occurred, unable to rename the mailbox." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία του γραμματοκιβωτίου.",
     "Mark all as read" : "Σημείωση όλων ως αναγνωσμένων",
     "Mark all messages of this folder as read" : "Σημείωση όλων των μυνημάτων ως αναγνωσμένων",
+    "Add subfolder" : "Προσθήκη υποφακέλου",
     "Rename" : "Μετονομασία",
+    "Move folder" : "Μετακίνηση φακέλου",
     "Clear cache" : "Εκκαθάριση προσωρινής μνήμης",
     "Clear locally cached data, in case there are issues with synchronization." : "Εκκαθαρίστε τα δεδομένα κρυφής μνήμης, σε περίπτωση που υπάρχουν προβλήματα με το συγχρονισμό.",
     "Subscribed" : "Εγγεγραμμένα",
