@@ -284,21 +284,20 @@ OC.L10N.register(
     "Moving" : "Moviendo",
     "Moving thread" : "Moviendo hilo",
     "Moving message" : "Moviendo mensaje",
-    "Loading …" : "Loading …",
-    "Not supported by the server" : "No es compatible con el servidor",
-    "{usage} of {limit} used" : "{usage} de {limit} usado",
     "Remove account" : "Eliminar cuenta",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "La cuenta para {email} y los datos de correo en caché se eliminarán de Nextcloud, pero no de tu proveedor de correo electrónico.",
     "Remove {email}" : "Eliminar {email}",
     "Provisioned account is disabled" : "La cuenta proporcionada está desactivada",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Inicia sesión usando una contraseña para habilitar esta cuenta. La sesión actual está utilizando autenticación sin contraseña, como SSO o WebAuthn.",
-    "Quota" : "Cuota",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Move up" : "Mover hacia arriba",
     "Move down" : "Mover hacia abajo",
+    "Show all folders" : "Mostrar todas las carpetas",
     "Collapse mailboxes" : "Colapsar buzones",
     "_{total} message_::_{total} messages_" : ["{total} mensaje","{total} mensajes","{total} mensajes"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} sin leer de {total}","{unread} sin leer de {total}","{unread} sin leer de {total}"],
+    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "Se eliminarán todos los mensajes del buzón.",
     "Clear mailbox {name}" : "Limpiar buzón {name}",
     "An error occurred, unable to rename the mailbox." : "Se produjo un error, no se puede cambiar el nombre del buzón.",
