@@ -80,7 +80,7 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
     "Remove account" : "Eliminar cuenta",
-    "Quota" : "Cuota",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Show all folders" : "Mostrar todas las carpetas",
     "Mark all as read" : "Marcar todos como leídos",
