@@ -101,6 +101,7 @@ OC.L10N.register(
     "Sieve script editor" : "Sieve skriptikoostaja",
     "Mail server" : "E-posti server",
     "Sieve server" : "Sieve server",
+    "Folder search" : "Kaustade otsing",
     "Update alias" : "Uuenda aliast",
     "Rename alias" : "Muuda aliast",
     "Show update alias form" : "Näita uuendatud aliast",
@@ -151,7 +152,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "Mailvelope on selle domeeni puhul kasutusel!",
     "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
-    "Install Mailvelope browser extension by clicking here" : "Klõpside siia paigalda Mailvelope'i brauserilaiendus",
     "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!",
     "Assistance features" : "Abilise funktsionaalsused",
     "About" : "Rakenduse teave",
@@ -235,6 +235,7 @@ OC.L10N.register(
     "The tag will be deleted from all messages." : "See silt saab olema eemaldatud kõikide kirjade juurest.",
     "Plain text" : "Vormindamata tekst",
     "Rich text" : "Vormindatud tekst",
+    "No messages in this folder" : "Selles kaustas pole kirju",
     "No messages" : "Kirju pole",
     "Blind copy recipients only" : "Vaid pimekoopia saajad",
     "No subject" : "Teemat pole",
@@ -247,6 +248,7 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
     "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
     "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
+    "No trash folder configured" : "Prügikasti kaust on määramata",
     "Could not delete message" : "Kirja kustutamine ei õnnestunud",
     "Could not archive message" : "Kirja arhiveerimine ei õnnestunud",
     "Thread was snoozed" : "Jutulõnga kuvamine on edasi lükatd",
@@ -329,10 +331,13 @@ OC.L10N.register(
     "Add internal address" : "Lisa sisene aadress",
     "Add internal email or domain" : "Lisa sisene e-posti aadress või domeen",
     "Itinerary for {type} is not supported yet" : "Reisiplaani tüüp pole veel toetatud: {type}",
+    "To archive a message please configure an archive folder in account settings" : "Kui tahad kirju arhiveerida, pead esmalt seadistustest valima arhiivikausta",
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Sul pole õigusi selle kirja arhiveerimiseks ega siit kaustast kustutamiseks või teisaldamiseks",
     "Your IMAP server does not support storing the seen/unseen state." : "Sinu e-posti server ei luba salvestada kirjade nähtud/mittenähtud olekuid.",
     "Could not mark message as seen/unseen" : "Ei õnnestunud märkida kirja nähtuks/mittenähtuks",
+    "Could not open folder" : "Kausta avamine ei õnnestunud",
     "Loading messages …" : "Laadin kirju…",
+    "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
     "Important info" : "Oluline teave",
@@ -382,31 +387,38 @@ OC.L10N.register(
     "Moving" : "Teisaldan",
     "Moving thread" : "Teisaldan jutulõnga mujale",
     "Moving message" : "Teisaldan kirja",
-    "Loading …" : "Laadin...",
-    "Not supported by the server" : "See pole serveri poolt toetatud",
-    "{usage} of {limit} used" : "Kasutusel: {usage} / {limit} ",
+    "Used quota: {quota}% ({limit})" : "Kasutatud kvoot: {quota}% ({limit})",
+    "Used quota: {quota}%" : "Kasutatud kvoot: {quota}%",
     "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "Postkasti pole võimalik luua. Ilmselt on nimes keelatud tähemärke. Palun proovi mõnda muud nime.",
     "Remove account" : "Eemalda konto",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "E-posti konto {email} ja tema puhverdatud andmed eemaldatakse siit Nextcloudi serverist, kuid mitte sinu e-postiteenuse pakkuja juurest.",
     "Remove {email}" : "Eemalda fail: „{email}“",
-    "Quota" : "Kvoot",
+    "Show only subscribed folders" : "Näita vaid tellitud kaustu",
     "Add folder" : "Lisa kaust",
     "Folder name" : "Kausta nimi",
     "Saving" : "Salvestan",
     "Move up" : "Liiguta ülespoole",
     "Move down" : "Liiguta allapoole",
+    "Show all subscribed folders" : "Näita kõiki tellitud kaustu",
     "Show all folders" : "Näita kõiki kaustu",
     "Collapse mailboxes" : "Ahenda postkastid",
     "_{total} message_::_{total} messages_" : ["{total} kiri","{total} kirja"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
+    "Loading …" : "Laadin...",
     "All messages in mailbox will be deleted." : "Kõik kirjad sellest postkastist  kustutatakse.",
     "Clear mailbox {name}" : "Tühjenda postkast: {name}",
+    "Clear folder" : "Tühjenda kaust",
+    "The folder and all messages in it will be deleted." : "Kaust ja kõik temas leiduvad kirjad saavad järgnevaga kustutatud.",
     "Delete folder" : "Kustuta kaust",
+    "Delete folder {name}" : "Kustuta kaust {name}",
     "An error occurred, unable to rename the mailbox." : "Tekkis viga ja postkasti nime muutmine pole võimalik.",
     "Please wait 10 minutes before repairing again" : "Enne uuesti parandamist palun oota 10 minutit",
     "Mark all as read" : "Märgi loetuks",
+    "Mark all messages of this folder as read" : "Märgi kõik selle kausta kirjad loetuks",
+    "Add subfolder" : "Lisa alamkaust",
     "Rename" : "Muuda nime",
-    "Move folder" : "Teisalda kausta",
+    "Move folder" : "Teisalda kaust",
+    "Repair folder" : "Paranda kaust",
     "Clear cache" : "Tühjenda puhver",
     "Clear locally cached data, in case there are issues with synchronization." : "Kui sünkroniseerimisel tekib vigu, siis kustuta kohalikus seadmes puhverdatud andmed.",
     "Subscribed" : "Tellitud",
@@ -421,6 +433,7 @@ OC.L10N.register(
     "Failed to save draft" : "Mustandi salvestamine ei õnnestu",
     "attachment" : "manus",
     "attached" : "manus on lisatud",
+    "No sent folder configured. Please pick one in the account settings." : "Saadetud kirjade kaust on seadistamata. Palun see seda kasutajakonto seadistustes.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sa üritad saata kirja, kus saaja ja koopia välja on hiidpalju aadresse. Kirjasaajate privaatsuse ja mugavuse nimel palun kasuta pimekoopia välja.",
     "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
     "You mentioned an attachment. Did you forget to add it?" : "Sa mainisid, et tahad manuse lisada. Kas see ununes?",
@@ -449,9 +462,12 @@ OC.L10N.register(
     "Save autoresponder" : "Salvesta automaatvastaja",
     "Could not open outbox" : "Saadetud kirjade postkasti ei olnud võimalik avada",
     "Pending or not sent messages will show up here" : "Ootel või saatmata kirjad saavad olema nähtavad siin.",
+    "Could not copy to \"Sent\" folder" : "Kirja on kopeerimine „Saadetud“ kausta ei õnnestunud",
     "Mail server error" : "E-posti serveri viga",
     "Message could not be sent" : "Kirja polnud võimalik saata",
     "Message deleted" : "Kiri on kustutatud",
+    "Copy to \"Sent\" Folder" : "Kopeeri „Saadetud“ kirjade kausta",
+    "Copy to Sent Folder" : "Kopeeri „Saadetud“ kirjade kausta",
     "Phishing email" : "Kurikaela õngitsuskiri",
     "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
     "Hide suspicious links" : "Peida kahtlased lingid",
@@ -468,6 +484,8 @@ OC.L10N.register(
     "Show less" : "Näita vähem",
     "Show more" : "Näita rohkem",
     "Clear" : "Tühjenda",
+    "Search in folder" : "Otsi kaustast",
+    "Open search modal" : "Ava modaalne otsinguvaade",
     "Close" : "Sulge",
     "Search parameters" : "Otsinguparameetrid",
     "Search subject" : "Otsi teemat",
@@ -529,6 +547,7 @@ OC.L10N.register(
     "The thread doesn't exist or has been deleted" : "Jutulõnga pole olemas või on kustutatud",
     "Email was not able to be opened" : "E-kirja polnud võimalik avada",
     "Print" : "Prindi",
+    "Could not print message" : "Kirja printimine ei õnnestunud",
     "Loading thread" : "Laadin jutulõnga",
     "Not found" : "Ei leidu",
     "Encrypted & verified " : "Krüptitud ja verifitseeritud",
@@ -659,6 +678,7 @@ OC.L10N.register(
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} serveris {host}:{port} ({ssl} krüptimisega)",
+    "Configuration for \"{provisioningDomain}\"" : "Seadistus „{provisioningDomain}“ domeeni jaoks",
     "Email address template" : "E-posti aadressi mall",
     "IMAP" : "IMAP",
     "User" : "Kasutaja",
@@ -721,6 +741,8 @@ OC.L10N.register(
     "Sending message…" : "Saadan kirja…",
     "Message sent" : "Kiri on saadetud",
     "Could not send message" : "Kirja saatmine ei õnnestu",
+    "Message copied to \"Sent\" folder" : "Kiri on kopeeritud „Saadetud“ kausta",
+    "Could not copy message to \"Sent\" folder" : "Kirja on kopeerimine „Saadetud“ kausta ei õnnestunud",
     "Could not load {tag}{name}{endtag}" : "Laadimine ei õnnestunud: {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Laadimisel tekkis viga: {tag}{name}{endtag}",
     "Could not load your message" : "Sinu kirja laadimine ei õnnestunud",
@@ -734,6 +756,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
     "Continue to %s" : "Jätka siia: %s",
     "Mailbox search" : "Postkasti otsing",
+    "Install Mailvelope browser extension by clicking here" : "Klõpside siia paigalda Mailvelope'i brauserilaiendus",
     "No messages in this mailbox" : "Selles postkastis pole kirju",
     "No trash mailbox configured" : "Prügikasti kaust on määramata",
     "Draft: " : "Kavand:",
