@@ -309,15 +309,11 @@ OC.L10N.register(
     "Moving" : "Moving",
     "Moving thread" : "Moving thread",
     "Moving message" : "Moving message",
-    "Loading …" : "بارگذاری …",
-    "Not supported by the server" : "Not supported by the server",
-    "{usage} of {limit} used" : "{usage} of {limit} used",
     "Remove account" : "حذف حساب کاربری",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
     "Remove {email}" : "Remove {email}",
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
-    "Quota" : "سهم",
     "Folder name" : "نام پوشه",
     "Saving" : "درحال ذخیره",
     "Move up" : "Move up",
@@ -326,6 +322,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Collapse mailboxes",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
+    "Loading …" : "بارگذاری …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "حذف پوشه",
