@@ -112,6 +112,7 @@ OC.L10N.register(
     "Trusted senders" : "Megbízható küldők",
     "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
     "Looking for a way to encrypt your emails?" : "Azt keresi, hogyan titkosíthatná a leveleit?",
+    "Install Mailvelope browser extension" : "Telepítse a Mailvelope böngészőkiegészítőt",
     "About" : "Névjegy",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
     "Compose new message" : "Új üzenet írása",
@@ -324,15 +325,11 @@ OC.L10N.register(
     "Moving" : "Áthelyezés",
     "Moving thread" : "Szál áthelyezése",
     "Moving message" : "Üzenet áthelyezése",
-    "Loading …" : "Betöltés…",
-    "Not supported by the server" : "A kiszolgáló nem támogatja",
-    "{usage} of {limit} used" : "{usage} / {limit} felhasználva",
     "Remove account" : "Fiók eltávolítása",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Az {email} fiók és a gyorsítótárazott e-mail-adatok el lesznek távolítva a Nextcloudból, az e-mail-szolgáltatójától azonban nem.",
     "Remove {email}" : "{email} eltávolítása",
     "Provisioned account is disabled" : "A felügyelt fiók le van tiltva",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Jelentkezzen be a jelszóval, hogy engedélyezze a fiókot. A jelenlegi munkamenet jelszó nélküli hitelesítést használ, például SSO-t vagy WebAuthnt.",
-    "Quota" : "Kvóta",
     "Add folder" : "Könyvtár hozzáadása",
     "Folder name" : "Mappanév",
     "Saving" : "Mentés",
@@ -342,6 +339,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Postaládák összecsukása",
     "_{total} message_::_{total} messages_" : ["{total} üzenet","{total} üzenet"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} olvasatlan az összesen {total} üzenetből","{unread} olvasatlan az összesen {total} üzenetből"],
+    "Loading …" : "Betöltés…",
     "All messages in mailbox will be deleted." : "A postaládában lévő összes üzenet végleges törlésre kerül.",
     "Clear mailbox {name}" : "A(z) {name} postaláda ürítése",
     "Delete folder" : "Mappa törlése",
