@@ -281,13 +281,9 @@ OC.L10N.register(
     "Moving" : "Spostamento",
     "Moving thread" : "Spostamento conversazione",
     "Moving message" : "Spostamento messaggio",
-    "Loading …" : "Caricamento in corso...",
-    "Not supported by the server" : "Non supportato dal server",
-    "{usage} of {limit} used" : "{usage} di {limit} utilizzati",
     "Remove account" : "Rimuovi account",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "L'account per {email} e i dati di posta elettronica memorizzati nella cache saranno rimossi da Nextcloud, ma non dal tuo fornitore di posta elettronica.",
     "Remove {email}" : "Rimuovi {email}",
-    "Quota" : "Quote",
     "Show only subscribed folders" : "Mostra solo le cartelle sottoscritte",
     "Add folder" : "Aggiungi cartella",
     "Folder name" : "Nome della cartella",
@@ -299,6 +295,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Contrai le caselle di posta",
     "_{total} message_::_{total} messages_" : ["{total} messaggio","{total} messaggi","{total} messaggi"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non letto di {total}","{unread} non letti di {total}","{unread} non letti di {total}"],
+    "Loading …" : "Caricamento in corso...",
     "The folder and all messages in it will be deleted." : "La cartella e tutti i messaggi in essa saranno eliminati.",
     "Delete folder" : "Elimina cartella",
     "Delete folder {name}" : "Elimina cartella {name}",
