@@ -147,7 +147,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "現在のドメインでMailvelopeが有効になっています!",
     "Looking for a way to encrypt your emails?" : "あなたのメールを暗号化する方法をお探しですか?",
-    "Install Mailvelope browser extension by clicking here" : "メールブラウザー拡張機能インストールしたい場合はここをクリックしてください",
     "Enable Mailvelope for the current domain" : "現在のドメインのMailvelopeを有効にする",
     "Assistance features" : "アシスタンス機能",
     "About" : "Nextcloud について",
@@ -376,15 +375,11 @@ OC.L10N.register(
     "Moving" : "移動中",
     "Moving thread" : "スレッドを移動しています",
     "Moving message" : "メッセージを移動しています",
-    "Loading …" : "読み込み中...",
-    "Not supported by the server" : "サーバーに対応していません",
-    "{usage} of {limit} used" : "{usage} / {limit} 使われています",
     "Remove account" : "アカウント削除",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email}のアカウントとキャッシュされたメールデータはNextcloudから削除されますが、メールプロバイダーからは削除されません。",
     "Remove {email}" : "{email} を削除",
     "Provisioned account is disabled" : "プロビジョニングされたアカウントは無効です",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "このアカウントを有効にするには、パスワードを使ってログインしてください。現在のセッションはシングルサインオンやWebAuthnなどのパスワードレス認証を使用しています。",
-    "Quota" : "クオータ",
     "Show only subscribed folders" : "登録されているフォルダーのみ表示",
     "Add folder" : "フォルダーを追加",
     "Folder name" : "フォルダー名",
@@ -396,6 +391,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "メールボックスを非表示",
     "_{total} message_::_{total} messages_" : ["{total} メッセージ"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} メッセージの内 {unread} 件が未開封"],
+    "Loading …" : "読み込み中...",
     "All messages in mailbox will be deleted." : "メールボックスにある全てのメッセージが削除されます。",
     "Clear mailbox {name}" : "メールボックス{name}を削除する",
     "Delete folder" : "フォルダーを削除",
@@ -750,6 +746,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
     "Continue to %s" : "%s にリダイレクトする",
     "Mailbox search" : "メールボックスの検索",
+    "Install Mailvelope browser extension by clicking here" : "メールブラウザー拡張機能インストールしたい場合はここをクリックしてください",
     "No messages in this mailbox" : "このメールボックスにメッセージはありません",
     "No trash mailbox configured" : "ゴミ箱メールボックスが設定されていません",
     "Draft: " : "下書き",
