@@ -119,7 +119,6 @@ OC.L10N.register(
     "Manage S/MIME certificates" : "Manage S/MIME certificates",
     "Mailvelope" : "Mailvelope",
     "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
-    "Install Mailvelope browser extension by clicking here" : "Install Mailvelope browser extension by clicking here",
     "About" : "About",
     "Keyboard shortcuts" : "Keyboard shortcuts",
     "Compose new message" : "Compose new message",
@@ -327,15 +326,11 @@ OC.L10N.register(
     "Moving" : "Moving",
     "Moving thread" : "Moving thread",
     "Moving message" : "Moving message",
-    "Loading …" : "Loading …",
-    "Not supported by the server" : "Not supported by the server",
-    "{usage} of {limit} used" : "{usage} of {limit} used",
     "Remove account" : "Remove account",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
     "Remove {email}" : "Remove {email}",
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
-    "Quota" : "Quota",
     "Folder name" : "Folder name",
     "Saving" : "Saving",
     "Move up" : "Move up",
@@ -343,6 +338,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Collapse mailboxes",
     "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
+    "Loading …" : "Loading …",
     "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
     "Clear mailbox {name}" : "Clear mailbox {name}",
     "Delete folder" : "Delete folder",
@@ -636,6 +632,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
     "Mailbox search" : "Mailbox search",
+    "Install Mailvelope browser extension by clicking here" : "Install Mailvelope browser extension by clicking here",
     "No messages in this mailbox" : "No messages in this mailbox",
     "No trash mailbox configured" : "No trash mailbox configured",
     "Draft: " : "Draft: ",
