@@ -116,7 +116,7 @@ OC.L10N.register(
     "Manage S/MIME certificates" : "S/MIME 인증서 관리",
     "Mailvelope" : "Mailvelope",
     "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
-    "Install Mailvelope browser extension by clicking here" : "여기를 눌러 Mailvelope 브라우저 확장기능을 설치하십시오",
+    "Install Mailvelope browser extension" : "Mailvelope 브라우저 확장 설치",
     "Keyboard shortcuts" : "키보드 단축키",
     "Compose new message" : "새 메시지 작성",
     "Newer message" : "새로운 메시지",
@@ -319,15 +319,11 @@ OC.L10N.register(
     "Moving" : "이동 중",
     "Moving thread" : "쓰레드 이동 중",
     "Moving message" : "메시지 이동 중",
-    "Loading …" : "불러오는 중 …",
-    "Not supported by the server" : "서버에서 지원하지 않음",
-    "{usage} of {limit} used" : "{limit} 중 {usage} 사용중",
     "Remove account" : "계정 삭제",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 계정 및 캐시된 이메일 데이터가 Nextcloud에서 삭제되지만, 이메일 서비스 제공자에서 삭제되지는 않습니다.",
     "Remove {email}" : "{email} 제거",
     "Provisioned account is disabled" : "프로비전된 계정을 비활성화 했습니다",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "이 계정을 활성화 하기 위해 암호를 사용하여 로그인 하십시오. 현재 세션은 무암호 인증을 사용하고 있습니다. 예) SSO, WebAuthn",
-    "Quota" : "할당량",
     "Add folder" : "폴더 추가",
     "Folder name" : "폴더 이름",
     "Saving" : "저장 중",
@@ -338,6 +334,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "편지함 접기",
     "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} 개 중 {unread} 개 읽지 않음"],
+    "Loading …" : "불러오는 중 …",
     "All messages in mailbox will be deleted." : "편지함에 있는 모든 메시지가 삭제됩니다",
     "Clear mailbox {name}" : "편지함 {name} 비우기",
     "Delete folder" : "폴더 삭제",
@@ -634,6 +631,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
     "Mailbox search" : "편지함 검색",
+    "Install Mailvelope browser extension by clicking here" : "여기를 눌러 Mailvelope 브라우저 확장기능을 설치하십시오",
     "No messages in this mailbox" : "이 편지함에 메시지가 없음",
     "No trash mailbox configured" : "휴지통 편지함이 설정되지 않음",
     "Draft: " : "초안:",
