@@ -241,13 +241,9 @@ OC.L10N.register(
     "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
     "Quoted text" : "Cituojamas tekstas",
     "Move" : "Perkelti",
-    "Loading …" : "Įkeliama…",
-    "Not supported by the server" : "Serveris nepalaiko",
-    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
     "Remove account" : "Šalinti paskyrą",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
     "Remove {email}" : "Šalinti {email}",
-    "Quota" : "Leidžiamas duomenų kiekis",
     "Show only subscribed folders" : "Rodyti tik prenumeruotus aplankus",
     "Add folder" : "Pridėti aplanką",
     "Folder name" : "Aplanko pavadinimas",
@@ -259,6 +255,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Suskleisti pašto dėžutes",
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
+    "Loading …" : "Įkeliama…",
     "All messages in mailbox will be deleted." : "Visi pašto dėžutėje esantys laiškai bus ištrinti.",
     "Clear mailbox {name}" : "Išvalyti pašto dėžutę {name}",
     "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
