@@ -86,7 +86,11 @@ OC.L10N.register(
     "Mail settings" : "Параметри за е-пошта",
     "Accounts" : "Сметки",
     "Add mail account" : "Додади е-пошта сметка",
+    "Settings for:" : "Параметри за:",
     "General" : "Општо",
+    "Layout" : "Распоред",
+    "Sorting" : "Сортирање",
+    "Newest" : "Најнови",
     "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
     "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
     "Register" : "Регистрирај се",
@@ -251,13 +255,9 @@ OC.L10N.register(
     "Move" : "Премести",
     "Moving" : "Преместува",
     "Moving message" : "Преместување порака",
-    "Loading …" : "Се вчитува…",
-    "Not supported by the server" : "Не е поддржано од серверот",
-    "{usage} of {limit} used" : "Искористено {usage} од {limit}",
     "Remove account" : "Отстрани сметка",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Сметката за {email} и зачуваните податоци ќе бидат избришани, но нема да бидат избришани од провајдерот на електронската пошта.",
     "Remove {email}" : "Одстрани {email}",
-    "Quota" : "Квота",
     "Show only subscribed folders" : "Прикажи само претплатени папки",
     "Add folder" : "Додади папка",
     "Folder name" : "Име на папка",
@@ -269,6 +269,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Сокриј сандачиња",
     "_{total} message_::_{total} messages_" : ["{total} порака","{total} пораки"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
+    "Loading …" : "Се вчитува…",
     "Clear mailbox {name}" : "Исчисти сандаче {name}",
     "The folder and all messages in it will be deleted." : "Папката и сите пораки во неа ќе бидат избришани.",
     "Delete folder" : "Избриши папка",
@@ -293,6 +294,8 @@ OC.L10N.register(
     "Error sending your message" : "Грешка при испраќање на пораката",
     "Retry" : "Обидете се повторно",
     "Send anyway" : "Испрати секако",
+    "Welcome to {productName} Mail" : "Добредојдовте во {productName} е-пошта",
+    "Start writing a message by clicking below or select an existing message to display its contents" : "Започнете да пишувате порака со кликнување подолу или изберете постоечка порака за да ја прикажете нејзината содржина",
     "Autoresponder off" : "Исклучен автоматски одговор",
     "Autoresponder on" : "Вклучен автоматски одговор",
     "First day" : "Прв ден",
@@ -410,6 +413,7 @@ OC.L10N.register(
     "Discard unsaved changes" : "Отфрли ги назачуваните промени",
     "Keep editing message" : "Продолжи со уредување на порака",
     "Attachments were not copied. Please add them manually." : "Пролозите на се копирани. Додадете ги рачно.",
+    "Sending message…" : "Испраќање на порака ...",
     "Message sent" : "Пораката е испратена",
     "Could not send message" : "Неможе да се испрати порака",
     "Could not load {tag}{name}{endtag}" : "Неможе да се вчита {tag}{name}{endtag}",
