@@ -141,7 +141,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "Mailvelope er aktivert for gjeldende domene!",
     "Looking for a way to encrypt your emails?" : "Leter du etter en måte å kryptere e-postene dine på?",
-    "Install Mailvelope browser extension by clicking here" : "Installer Mailvelope-nettleserutvidelse ved å klikk her",
     "Enable Mailvelope for the current domain" : "Aktiver Mailvelope for gjeldende domene",
     "Assistance features" : "Assistanse funksjoner",
     "About" : "Om",
@@ -369,15 +368,11 @@ OC.L10N.register(
     "Moving" : "Flytter",
     "Moving thread" : "Flytter tråd",
     "Moving message" : "Flytter melding",
-    "Loading …" : "Laster...",
-    "Not supported by the server" : "Støttes ikke av serveren",
-    "{usage} of {limit} used" : "{usage} av {limit} brukt",
     "Remove account" : "Fjern konto",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Kontoen for {email} og bufrede e-postdata vil bli fjernet fra Nextcloud, men ikke fra e-postleverandøren din.",
     "Remove {email}" : "Fjern {email}",
     "Provisioned account is disabled" : "Klargjort konto er deaktivert",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Vennligst logg inn med et passord for å aktivere denne kontoen. Den nåværende økten bruker passordløs autentisering, for eksempel SSO eller WebAuthn.",
-    "Quota" : "Kvote",
     "Add folder" : "Legg til mappe",
     "Folder name" : "Mappenavn",
     "Saving" : "Lagrer",
@@ -387,6 +382,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Skjul postkasser",
     "_{total} message_::_{total} messages_" : ["{total} melding","{total} meldinger"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ulest av {total}","{unread} uleste av {total}"],
+    "Loading …" : "Laster...",
     "All messages in mailbox will be deleted." : "Alle meldinger i postkassen blir slettet.",
     "Clear mailbox {name}" : "Tøm postboks {name}",
     "Delete folder" : "Slett mappe",
@@ -709,6 +705,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
     "Mailbox search" : "Søk i postboks",
+    "Install Mailvelope browser extension by clicking here" : "Installer Mailvelope-nettleserutvidelse ved å klikk her",
     "No messages in this mailbox" : "Ingen meldinger i denne postboksen",
     "No trash mailbox configured" : "Ingen søppelpostkasse konfigurert",
     "Draft: " : "Kladd:",
