@@ -123,6 +123,7 @@ OC.L10N.register(
     "Trusted senders" : "Zaufani nadawcy",
     "Manage S/MIME certificates" : "Zarządzaj certyfikatami S/MIME",
     "Looking for a way to encrypt your emails?" : "Szukasz sposobu na szyfrowanie wiadomości e-mail?",
+    "Install Mailvelope browser extension" : "Zainstaluj rozszerzenie przeglądarki Mailvelope",
     "Assistance features" : "Asystent",
     "About" : "O aplikacji",
     "Keyboard shortcuts" : "Skróty klawiaturowe",
@@ -312,15 +313,11 @@ OC.L10N.register(
     "Moving" : "przenoszenie",
     "Moving thread" : "Przenoszenie wątku",
     "Moving message" : "Przenoszenie wiadomości",
-    "Loading …" : "Wczytywanie…",
-    "Not supported by the server" : "Niewspierany przez serwer",
-    "{usage} of {limit} used" : "Użyto {usage} z {limit}",
     "Remove account" : "Usuń konto",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Konto dla {email} i zapisane w pamięci podręcznej dane e-mail zostaną usunięte z Nextcloud, ale pozostaną nadal u dostawcy poczty e-mail.",
     "Remove {email}" : "Usuń {email}",
     "Provisioned account is disabled" : "Zabezpieczone konto jest wyłączone",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Zaloguj się przy użyciu hasła, aby włączyć to konto. Bieżąca sesja korzysta z uwierzytelniania bez hasła, m.in. SSO lub WebAuthn.",
-    "Quota" : "Limit",
     "Show only subscribed folders" : "Pokaż tylko subskrybowane foldery",
     "Add folder" : "Dodaj katalog",
     "Folder name" : "Nazwa katalogu",
@@ -332,6 +329,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Zwiń skrzynki pocztowe",
     "_{total} message_::_{total} messages_" : ["{total} wiadomość","{total} wiadomości","{total} wiadomości","{total} wiadomości"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nieprzeczytana z {total}","{unread} nieprzeczytane z {total}","{unread} nieprzeczytanych z {total}","{unread} nieprzeczytanych z {total}"],
+    "Loading …" : "Wczytywanie…",
     "All messages in mailbox will be deleted." : "Wszystkie wiadomości w skrzynce pocztowej zostaną usunięte.",
     "Clear mailbox {name}" : "Wyczyść skrzynkę pocztową {name}",
     "The folder and all messages in it will be deleted." : "Folder i wszystkie zawarte w nim wiadomości zostaną usunięte.",
