@@ -141,17 +141,14 @@ OC.L10N.register(
     "Always show images from {domain}" : "Mostrar sempre as imagem de {domain}",
     "Move" : "Mover",
     "Moving" : "A mover",
-    "Loading …" : "A carregar...",
-    "Not supported by the server" : "Não é suportado pelo servidor",
-    "{usage} of {limit} used" : "Usado {usage}  {limit}",
     "Remove account" : "Remover conta",
     "Remove {email}" : "Remover {email}",
-    "Quota" : "Quota",
     "Folder name" : "Nome da pasta",
     "Saving" : "A guardar",
     "Move up" : "Mover para cima",
     "Move down" : "Mover para baixo",
     "Show all folders" : "Mostrar todas as pastas",
+    "Loading …" : "A carregar...",
     "Delete folder" : "Apagar pasta",
     "Mark all as read" : "Marcar todas como lidas",
     "Rename" : "Renomear",
