@@ -300,15 +300,11 @@ OC.L10N.register(
     "Moving" : "Se mută",
     "Moving thread" : "Mută conversația",
     "Moving message" : "Se mută mesajul",
-    "Loading …" : "Se încarcă…",
-    "Not supported by the server" : "Incompatibil cu serverul",
-    "{usage} of {limit} used" : "{usage} din {limit} utilizat",
     "Remove account" : "Sterge contul",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Contul pentru {email} și datele din cache vor fi eliminate din Nextcloud, dar nu și de la providerul de mail.",
     "Remove {email}" : "Șterge {email}",
     "Provisioned account is disabled" : "Contul configurat este dezactivat",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Logați-vă cu o parolă pentru a activa acest cont. Sesiunea curentă utilizează autentificarea fără parolă, de ex. SSO sau WebAuthn.",
-    "Quota" : "Procent",
     "Folder name" : "Denumire director",
     "Saving" : "Se salvează",
     "Move up" : "Mută înainte",
@@ -317,6 +313,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Restrânge folderele",
     "_{total} message_::_{total} messages_" : ["{total} mesaj","{total} mesaje","{total} mesaje"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} necitit din {total}","{unread} necitite din {total}","{unread} necitite din {total}"],
+    "Loading …" : "Se încarcă…",
     "All messages in mailbox will be deleted." : "Vor fi șterse toate mesajele din acest folder",
     "Clear mailbox {name}" : "Golește folderul {name}",
     "An error occurred, unable to rename the mailbox." : "Eroare la redenumirea mailbox.",
