@@ -142,7 +142,7 @@ OC.L10N.register(
     "Mailvelope" : "Почтовый конверт",
     "Mailvelope is enabled for the current domain!" : "Mailvelope включен для текущего домена!",
     "Looking for a way to encrypt your emails?" : "Необходимо использовать шифрование электронных писем?",
-    "Install Mailvelope browser extension by clicking here" : "Установите расширение браузера Mailvelope, нажав здесь",
+    "Install Mailvelope browser extension" : "Установите расширение для браузера Mailvelope",
     "Enable Mailvelope for the current domain" : "Включить почтовый конверт для текущего домена",
     "Assistance features" : "Функции помощи",
     "About" : "О себе",
@@ -357,15 +357,11 @@ OC.L10N.register(
     "Moving" : "Выполняется перемещение",
     "Moving thread" : "Перемещение ветки",
     "Moving message" : "Сообщение перемещается",
-    "Loading …" : "Загрузка ...",
-    "Not supported by the server" : "Функция не поддерживается сервером",
-    "{usage} of {limit} used" : "Используется {usage} из {limit}",
     "Remove account" : "Удалить учётную запись",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Учётная запись {email} и сохранённые данные будут удалены из Nextcloud, но сохранятся на исходном почтовом сервере.",
     "Remove {email}" : "Удалить {email}",
     "Provisioned account is disabled" : "Предоставленный аккаунт отключен",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Пожалуйста, войдите в систему, используя пароль, чтобы активировать эту учетную запись. Текущий сеанс использует аутентификацию без пароля, например. Единый вход или WebAuthn.",
-    "Quota" : "Квота",
     "Show only subscribed folders" : "Показывать только папки из подписки",
     "Add folder" : "Добавить папку",
     "Folder name" : "Имя папки",
@@ -376,6 +372,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Свернуть папки",
     "_{total} message_::_{total} messages_" : ["{total} письмо","{total} письма","{total} писем","{total} письма"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}"],
+    "Loading …" : "Загрузка ...",
     "All messages in mailbox will be deleted." : "Все сообщения в почтовом ящике будут удалены.",
     "Clear mailbox {name}" : "Очистить почтовый ящик {name}",
     "The folder and all messages in it will be deleted." : "Папка и все находящиеся в ней письма будут удалены",
@@ -692,6 +689,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>",
     "Continue to %s" : "Продолжать %s",
     "Mailbox search" : "Поиск по почтовому ящику",
+    "Install Mailvelope browser extension by clicking here" : "Установите расширение браузера Mailvelope, нажав здесь",
     "No messages in this mailbox" : "В этой папке нет сообщений",
     "No trash mailbox configured" : "Папка «Удалённые» не настроена",
     "Draft: " : "Черновик:",
