@@ -285,14 +285,10 @@ OC.L10N.register(
     "Moving" : "Premikanje",
     "Moving thread" : "Poteka premikanje niti ...",
     "Moving message" : "Poteka premikanje sporočila ...",
-    "Loading …" : "Poteka nalaganje …",
-    "Not supported by the server" : "Opravilo na strežniku ni podprto",
-    "{usage} of {limit} used" : "Uporabljeno je {usage} od {limit} prostora.",
     "Remove account" : "Odstrani račun",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} in podatki tega računa v predpomnilniku bodo odstranjeni iz oblaka Nextcloud, ne pa tudi iz poštnega računa pri ponudniku storitve.",
     "Remove {email}" : "Odstrani {email}",
     "Provisioned account is disabled" : "Povezan račun je onemogočen",
-    "Quota" : "Količinska omejitev",
     "Show only subscribed folders" : "Pokaži le naročene mape",
     "Add folder" : "Dodaj mapo",
     "Folder name" : "Ime mape",
@@ -304,6 +300,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Skrči poštne predale",
     "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
+    "Loading …" : "Poteka nalaganje …",
     "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
     "Clear mailbox {name}" : "Počisti poštni predal {name}",
     "The folder and all messages in it will be deleted." : "Mapa in vsa sporočila bodo izbrisana.",
