@@ -13,6 +13,7 @@ OC.L10N.register(
     "Password" : "Nenosiri",
     "None" : "Hakuna",
     "Signature" : "Saini",
+    "Filters" : "Filters",
     "Go back" : "Rudi nyuma",
     "Email address" : "Anwani ya barua pepe",
     "Cancel" : "Cancel",
@@ -44,6 +45,7 @@ OC.L10N.register(
     "Set reminder for next week" : "Set reminder for next week",
     "Favorite" : "Kipendwa",
     "Unread" : "Unread",
+    "Read" : "Soma",
     "More actions" : "Vitendo zaidi",
     "Back" : "Rudi",
     "Create event" : "Tengeneza matukio",
@@ -63,19 +65,21 @@ OC.L10N.register(
     "Forward" : "Mbele",
     "Translate" : "Tafsiri",
     "Move" : "Hamisha",
-    "Loading …" : "Inapakia",
-    "{usage} of {limit} used" : "{usage} ya {limit}imetumika",
     "Remove account" : "Ondoa akaunti",
     "Add folder" : "Ongeza kisanduku",
     "Folder name" : "Jina la kisanduku",
+    "Loading …" : "Inapakia",
     "Delete folder" : "Futa kisanduku",
     "Rename" : "Ipe jina jipya",
     "Subscribed" : "Iliyojisajili",
     "Edit message" : "Hariri ujumbe",
+    "Draft" : "Draft",
     "Reply" : "Jibu",
     "Retry" : "Jaribu tene",
     "Copy to clipboard" : "Nakili kwenye ubao wa kunakili",
     "Add" : "Ongeza",
+    "Show less" : "Show less",
+    "Show more" : "Show more",
     "Clear" : "Futa",
     "Close" : "Funga",
     "Date" : "Tarehe",
@@ -89,6 +93,7 @@ OC.L10N.register(
     "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
     "Untitled event" : "Tukio lisilotajwa",
     "(organizer)" : "(Mratibu)",
+    "matches" : "matches",
     "Priority" : "Kipaumbele",
     "Reset" : "Pangilia upya",
     "Client ID" : "Kitambulisho cha mteja",
@@ -103,6 +108,7 @@ OC.L10N.register(
     "All" : "Zote",
     "Favorites" : "Vipendwa",
     "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
+    "Discard changes" : "Discard changes",
     "Message sent" : "Ujumbe umetumwa",
     "Redirect" : "Elekeza upya",
     "Continue to %s" : "Endelea katika %s",
