@@ -145,7 +145,6 @@ OC.L10N.register(
     "Mailvelope" : "Mailvelope",
     "Mailvelope is enabled for the current domain!" : "خەت ساندۇقى نۆۋەتتىكى دائىرە ئۈچۈن قوزغىتىلدى!",
     "Looking for a way to encrypt your emails?" : "ئېلېكترونلۇق خەتلىرىڭىزنى مەخپىيلەشتۈرۈشنىڭ يولىنى ئىزدەۋاتامسىز؟",
-    "Install Mailvelope browser extension by clicking here" : "بۇ يەرنى چېكىپ Mailvelope توركۆرگۈ كېڭەيتىلمىسىنى قاچىلاڭ",
     "Enable Mailvelope for the current domain" : "نۆۋەتتىكى دائىرە ئۈچۈن Mailvelope نى قوزغىتىڭ",
     "Assistance features" : "ياردەم ئىقتىدارلىرى",
     "About" : "ھەققىدە",
@@ -357,21 +356,18 @@ OC.L10N.register(
     "Moving" : "يۆتكىلىش",
     "Moving thread" : "يۆتكىلىشچان تېما",
     "Moving message" : "يۆتكىلىشچان ئۇچۇر",
-    "Loading …" : "Loading…",
-    "Not supported by the server" : "مۇلازىمېتىر قوللىمايدۇ",
-    "{usage} of {limit} used" : "{usage} of {limit} ئىشلىتىلگەن",
     "Remove account" : "ھېساباتنى ئۆچۈرۈڭ",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} خەت} ۋە غەملەك ئېلېكترونلۇق خەت سانلىق مەلۇماتلىرىنىڭ ھېساباتى Nextcloud دىن ئۆچۈرۈلىدۇ ، ئەمما ئېلېكترونلۇق خەت تەمىنلىگۈچىڭىزدىن ئۆچۈرۈلمەيدۇ.",
     "Remove {email}" : "Remove {email}",
     "Provisioned account is disabled" : "تەمىنلەنگەن ھېسابات چەكلەنگەن",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "بۇ ھېساباتنى قوزغىتىش ئۈچۈن پارول ئىشلىتىپ كىرىڭ. نۆۋەتتىكى يىغىن مەخپىي نومۇرسىز دەلىللەشنى ئىشلىتىۋاتىدۇ. SSO ياكى WebAuthn.",
-    "Quota" : "Quota",
     "Add folder" : "قىسقۇچ قوشۇڭ",
     "Folder name" : "ھۆججەت قىسقۇچنىڭ ئىسمى",
     "Saving" : "تېجەش",
     "Move up" : "يۆتكەڭ",
     "Move down" : "تۆۋەنگە يۆتكەڭ",
     "Collapse mailboxes" : "خەت ساندۇقىنى يىمىرىڭ",
+    "Loading …" : "Loading…",
     "All messages in mailbox will be deleted." : "خەت ساندۇقىدىكى بارلىق ئۇچۇرلار ئۆچۈرۈلىدۇ.",
     "Clear mailbox {name}" : "خەت ساندۇقىنى تازىلاش {name}",
     "Delete folder" : "ھۆججەت قىسقۇچنى ئۆچۈرۈڭ",
@@ -719,6 +715,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
     "Continue to %s" : "داۋاملىق% s",
     "Mailbox search" : "خەت ساندۇقى ئىزدەش",
+    "Install Mailvelope browser extension by clicking here" : "بۇ يەرنى چېكىپ Mailvelope توركۆرگۈ كېڭەيتىلمىسىنى قاچىلاڭ",
     "No messages in this mailbox" : "بۇ خەت ساندۇقىدا ھېچقانداق ئۇچۇر يوق",
     "No trash mailbox configured" : "ئەخلەت خەت ساندۇقى سەپلەنمىگەن",
     "Draft: " : "لايىھە: ",
