@@ -120,7 +120,6 @@ OC.L10N.register(
     "Trusted senders" : "Довірені адресати",
     "Manage S/MIME certificates" : "Керування сертифікатами S/MIME",
     "Looking for a way to encrypt your emails?" : "Шукаєте спосіб зашифрувати свою електронну пошту?",
-    "Install Mailvelope browser extension by clicking here" : "Щоби встановити розширення Mailvelope для бравзера, клацніть тут",
     "About" : "Про сервіс",
     "Keyboard shortcuts" : "Скорочення",
     "Compose new message" : "Нове повідомлення",
@@ -326,13 +325,9 @@ OC.L10N.register(
     "Moving" : "Переміщення",
     "Moving thread" : "Переміщення ланцюжка",
     "Moving message" : "Переміщення повідомлення",
-    "Loading …" : "Завантаження...",
-    "Not supported by the server" : "Не підтримується сервером",
-    "{usage} of {limit} used" : "Використано {usage} із {limit}",
     "Remove account" : "Вилучити обліковий запис",
     "Remove {email}" : "Вилучити {email}",
     "Provisioned account is disabled" : "Автоматично налаштований обліковий запис вимкнено",
-    "Quota" : "Обмеження",
     "Show only subscribed folders" : "Показувати лише підписані теки",
     "Add folder" : "Додати теку",
     "Folder name" : "Назва каталогу",
@@ -344,6 +339,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Згорнути поштові скриньки",
     "_{total} message_::_{total} messages_" : ["{total} повідомлення","{total} повідомлення","{total} повідомлень","{total} повідомлень"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}","{unread} непрочитано з {total}"],
+    "Loading …" : "Завантаження...",
     "All messages in mailbox will be deleted." : "Усі повідомлення у поштовій скриньці буде вилучено.",
     "Clear mailbox {name}" : "Очистити поштову скриньку {name}",
     "Delete folder" : "Вилучити каталог",
@@ -557,6 +553,7 @@ OC.L10N.register(
     "The link leads to %s" : "Посилання веде до %s",
     "Continue to %s" : "Перейти до %s",
     "Mailbox search" : "Пошук поштової скриньки",
+    "Install Mailvelope browser extension by clicking here" : "Щоби встановити розширення Mailvelope для бравзера, клацніть тут",
     "No messages in this mailbox" : "Відсутні листи у поштовій скриньці",
     "No trash mailbox configured" : "Кошик для листів не налаштовано",
     "Draft: " : "Чернетка:",
