@@ -161,13 +161,9 @@ OC.L10N.register(
     "Quoted text" : "Văn bản được trích dẫn",
     "Move" : "Dịch chuyển",
     "Moving" : "Di chuyển",
-    "Loading …" : "Đang tải...",
-    "Not supported by the server" : "Không được máy chủ hỗ trợ",
-    "{usage} of {limit} used" : "Đã sử dụng {use} trong tổng số {limit}",
     "Remove account" : "Xóa tài khoản",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tài khoản cho {email} và dữ liệu email đã lưu trong bộ nhớ cache sẽ bị xóa khỏi vWorkspace, nhưng không bị xóa khỏi nhà cung cấp dịch vụ email của bạn.",
     "Remove {email}" : "Xóa {email}",
-    "Quota" : "Hạn ngạch",
     "Folder name" : "Tên thư mục",
     "Saving" : "Tiết kiệm",
     "Move up" : "Di chuyển lên",
@@ -175,6 +171,7 @@ OC.L10N.register(
     "Collapse mailboxes" : "Thu gọn hộp thư",
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
+    "Loading …" : "Đang tải...",
     "Delete folder" : "Xoá thư mục",
     "An error occurred, unable to rename the mailbox." : "Đã xảy ra lỗi, không thể đổi tên hộp thư.",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
